@@ -4,7 +4,7 @@ use Moose;
 use Scalar::Util 'blessed';
 with 'Dist::Zilla::Role::PluginBundle::Easy', 'Dist::Zilla::Role::PluginBundle::Config::Slicer';
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 sub configure {
 	my $self = shift;
@@ -24,14 +24,12 @@ sub configure {
 	$self->add_plugins([ReadmeAnyFromPod => 'Readme_Github' => { type => 'pod', filename => 'README.pod', location => 'root' }]);
 	$self->add_plugins('MetaProvides::Package', 'Prereqs::FromCPANfile', 'Git::Contributors');
 	$self->add_plugins([MetaNoIndex => { directory => [ qw/t xt inc share eg examples/ ] }]);
-	# Add this bundle as develop requires
-	$self->add_plugins([Prereqs => 'Self_Prereq' => { -phase => 'develop', (blessed $self) => $self->VERSION }]);
 	
-	my @from_release = qw(INSTALL LICENSE META.json);
+	my @from_build = qw(INSTALL LICENSE META.json);
 	if ($installer =~ /^ModuleBuild/) {
-		push @from_release, 'Build.PL';
+		push @from_build, 'Build.PL';
 	} else {
-		push @from_release, 'Makefile.PL';
+		push @from_build, 'Makefile.PL';
 	}
 	my @ignore_files = qw(Build.PL Makefile.PL);
 	my $ignore_match = '^CONTRIBUTING\.';
@@ -41,11 +39,10 @@ sub configure {
 	# @Git and versioning
 	$self->add_plugins(
 		'CheckChangesHasContent',
-		['Git::Check' => { allow_dirty => \@dirty_files }],
+		['Git::Check' => { allow_dirty => [@dirty_files, @from_build] }],
 		'RewriteVersion',
 		[NextRelease => { format => '%-9v %{yyyy-MM-dd HH:mm:ss VVV}d%{ (TRIAL RELEASE)}T' }],
-		[CopyFilesFromRelease => { filename => \@from_release }],
-		['Git::Commit' => { allow_dirty => [@dirty_files, @from_release], allow_dirty_match => $versioned_match, add_files_in => '/' }],
+		['Git::Commit' => { allow_dirty => [@dirty_files, @from_build], allow_dirty_match => $versioned_match, add_files_in => '/' }],
 		'Git::Tag',
 		[BumpVersionAfterRelease => { munge_makefile_pl => 0 }],
 		['Git::Commit' => 'Commit_Version_Bump' => { allow_dirty_match => $versioned_match, commit_msg => 'Bump version' }],
@@ -57,7 +54,9 @@ sub configure {
 		$self->add_plugins('PodCoverageTests') unless $self->payload->{pod_tests} eq 'syntax';
 	}
 	
-	$self->add_plugins(['Git::GatherDir' => { exclude_filename => [@ignore_files, @from_release], exclude_match => $ignore_match }]);
+	$self->add_plugins(
+		['Git::GatherDir' => { exclude_filename => [@ignore_files, @from_build], exclude_match => $ignore_match }],
+		[CopyFilesFromBuild => { copy => \@from_build }]);
 	# @Basic, with some modifications
 	$self->add_plugins(qw/PruneCruft ManifestSkip MetaYAML MetaJSON
 		License ReadmeAnyFromPod ExtraTests ExecDir ShareDir/);
@@ -107,23 +106,18 @@ This is the plugin bundle that DBOOK uses. It is equivalent to:
  directory = eg
  directory = examples
  
- [Prereqs / Self_Prereq]
- -phase = develop
- Dist::Zilla::PluginBundle::Author::DBOOK = $VERSION
- 
  [CheckChangesHasContent]
  [Git::Check]
  allow_dirty = dist.ini
  allow_dirty = Changes
  allow_dirty = README.pod
+ allow_dirty = INSTALL
+ allow_dirty = LICENSE
+ allow_dirty = META.json
+ allow_dirty = Makefile.PL
  [RewriteVersion]
  [NextRelease]
  format = %-9v %{yyyy-MM-dd HH:mm:ss VVV}d%{ (TRIAL RELEASE)}T
- [CopyFilesFromRelease]
- filename = INSTALL
- filename = LICENSE
- filename = META.json
- filename = Makefile.PL
  [Git::Commit]
  add_files_in = /
  allow_dirty_match = ^(?:lib|script|bin)/
@@ -149,6 +143,11 @@ This is the plugin bundle that DBOOK uses. It is equivalent to:
  exclude_filename = Makefile.PL
  exclude_filename = Build.PL
  exclude_match = ^CONTRIBUTING\.
+ [CopyFilesFromBuild]
+ copy = INSTALL
+ copy = LICENSE
+ copy = META.json
+ copy = Makefile.PL
  [PruneCruft]
  [ManifestSkip]
  [MetaYAML]
@@ -170,7 +169,7 @@ This is the plugin bundle that DBOOK uses. It is equivalent to:
 This bundle assumes that your git repo has the following: a L<cpanfile> with
 the dist's prereqs, a C<Changes> populated for the current version (see
 L<Dist::Zilla::Plugin::NextRelease>), and a C<.gitignore> including
-C<Name-Of-Dist-*> but not C<Makefile.PL>/C<Build.PL> or C<META.json>.
+C</Name-Of-Dist-*> but not C<Makefile.PL>/C<Build.PL> or C<META.json>.
 
 To test releasing, set the env var C<FAKE_RELEASE=1> to run everything except
 the upload to CPAN.
